==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Робота</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Життя</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Інше</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Закрити</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>За день до початку</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Нагадати мені завтра</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Нагадати мені пізніше</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>За 15 хвилин</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>За 1 годину</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>За 4 години</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Завтра</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Розклад нагадування</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>з %1 до %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Сьогодні</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">За день до початку</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Закрити</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Нагадати мені завтра</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Нагадати мені пізніше</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Планування нагадування</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">з %1 до %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Сьогодні</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Взавтра</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.14.orig.tar.xz: dde-calendar-5.9.14/translations/dde-calendar-service_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Робота</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Життя</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Інше</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Закрити</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>За день до початку</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Нагадати мені завтра</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Нагадати мені пізніше</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>За 15 хвилин</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>За 1 годину</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>За 4 години</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Завтра</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Розклад нагадування</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>з %1 до %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Сьогодні</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
